@@ -47,8 +47,8 @@ public:
   virtual void on_box_databases_selected(Glib::ustring strName);
   virtual void on_box_tables_selected(Glib::ustring strName);
 
-  virtual void on_menu_userlevel_Developer(Glib::RefPtr<Gtk::RadioAction> action);
-  virtual void on_menu_userlevel_Operator(Glib::RefPtr<Gtk::RadioAction> action);
+  virtual void on_menu_userlevel_Developer(const Glib::RefPtr<Gtk::RadioAction>& action);
+  virtual void on_menu_userlevel_Operator(const Glib::RefPtr<Gtk::RadioAction>& action);
       
   virtual void on_menu_Mode_Data();
   virtual void on_menu_Mode_Find();
@@ -62,6 +62,7 @@ public:
   virtual void on_menu_developer_relationships();
   virtual void on_menu_developer_users();     
   virtual void on_menu_developer_layout();
+  virtual void on_menu_developer_recreate_structure(); 
 
   virtual void on_developer_dialog_hide();
 
@@ -77,6 +78,8 @@ public:
   enumModes m_Mode;
   enumModes m_Mode_Previous; // see comments in set_mode_widget().
 
+  static void show_ok_dialog(const Glib::ustring& title, const Glib::ustring& message, Gtk::Window& parent);
+
 protected:
 
   //virtual void set_document(Document_Glom* pDocument); //override
@@ -91,7 +94,6 @@ protected:
   virtual Gtk::Window* get_app_window();
   virtual const Gtk::Window* get_app_window() const;
   
-  virtual void show_ok_dialog(const Glib::ustring& title, const Glib::ustring& message);
   virtual void alert_no_table();
   
   //Signal handlers:
