@@ -18,12 +18,14 @@
  * Boston, MA 02111-1307, USA.
  */
 
+//We use Python for calculated fields.
+#include <Python.h> //Include it before anything else to avoid "_POSIX_C_SOURCE redefined".
+
 //#include <gnome.h>
 #include <gtkmm/main.h>
 #include <libgnome/gnome-init.h> // For gnome_program_init().
 
-//We use Python for calculated fields.
-//#include <Python.h>
+
 
 #include "config.h" //For VERSION.
 
@@ -52,7 +54,7 @@ main(int argc, char* argv[])
   }
 
   //We use python for calculated-fields:
-  //PyInitialize();
+  Py_Initialize();
   
   try
   {
@@ -70,9 +72,13 @@ main(int argc, char* argv[])
 
     pApp_Glom->set_command_line_args(argc, argv);
 
-    pApp_Glom->init(input_uri); //Sets it up and shows it.
-
-    Gtk::Main::run();
+    bool test = pApp_Glom->init(input_uri); //Sets it up and shows it.
+    if(test) //The user could cancel the offer of a new or existing database.
+    {
+      Gtk::Main::run();
+    }
+    else
+      delete pApp_Glom;
   }
   catch(const std::exception& ex)
   {
@@ -80,7 +86,7 @@ main(int argc, char* argv[])
   }
 
   //We use python for calculated-fields:
-  //PyFinalize();
+  Py_Finalize();
   
   return 0;
 }
