@@ -28,9 +28,11 @@
 #include "../../utility_widgets/table_columns.h"
 #include "../../utility_widgets/entry_numerical.h"
 #include "../../utility_widgets/dialog_properties.h"
+#include "../../utility_widgets/datawidget.h"
 #include "../../data_structure/field.h"
 #include "../../base_db.h"
 
+
 class Dialog_FieldDefinition
  : public Dialog_Properties,
    public Base_DB //Give this class access to the current document, and to some utility methods.
@@ -48,6 +50,8 @@ protected:
   void on_combo_type_changed();
   void on_combo_lookup_relationship_changed();
   void on_check_lookup_toggled();
+  void on_check_calculate_toggled();
+  void on_button_edit_calculation();
   
   //void on_foreach(Gtk::Widget& widget);
 
@@ -58,8 +62,7 @@ protected:
   Combo_FieldType* m_pCombo_Type;
   Gtk::CheckButton* m_pCheck_Unique;
   Gtk::CheckButton* m_pCheck_NotNull;
-  Gtk::Entry* m_pEntry_Default;
-  Gtk::Label* m_pLabel_Default;
+  Gtk::HBox* m_pBox_DefaultValueSimple;
   Gtk::CheckButton* m_pCheck_PrimaryKey;
   Gtk::CheckButton* m_pCheck_AutoIncrement;
 
@@ -69,8 +72,15 @@ protected:
   Combo_LookupRelationship* m_pCombo_LookupRelationship;
   Combo_TextGlade* m_pCombo_LookupField;
 
+  Gtk::CheckButton* m_pCheck_Calculate;
+  Gtk::Alignment* m_pAlignment_Calculate;
+  Gtk::TextView* m_pTextView_Calculation;
+  Gtk::Button* m_pButton_EditCalculation;
+     
   Gtk::Entry* m_pEntry_Title;
 
+  DataWidget* m_pDataWidget_DefaultValueSimple;
+
   Field m_Field;
   Glib::ustring m_table_name;
 };
