@@ -24,6 +24,7 @@
 
 Box_DataBases::Box_DataBases(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
 : Box_DB(cobject),
+  m_button_connect(0),
   m_col_name(0)
 {
   m_AddDel.set_show_column_titles(false);
@@ -35,8 +36,7 @@ Box_DataBases::Box_DataBases(BaseObjectType* cobject, const Glib::RefPtr<Gnome::
   refGlade->get_widget("entry_connection_user", m_Entry_User);
   refGlade->get_widget("entry_connection_password", m_Entry_Password);
 
-  Gtk::Button* pButtonConnect = 0;
-  refGlade->get_widget("button_connect", pButtonConnect);
+  refGlade->get_widget("button_connect", m_button_connect);
   refGlade->get_widget("expander_tables", m_Expander_Tables);
 
   Gtk::Button* pButtonCancel = 0;
@@ -48,16 +48,16 @@ Box_DataBases::Box_DataBases(BaseObjectType* cobject, const Glib::RefPtr<Gnome::
       
   m_bUseList = false; //set to true later by call to set_use_list().
 
-  pButtonConnect->signal_clicked().connect(sigc::mem_fun(*this, &Box_DataBases::on_button_connect));
+  m_button_connect->signal_clicked().connect(sigc::mem_fun(*this, &Box_DataBases::on_button_connect));
 
   pAligmentPlaceholder->add(m_AddDel);
 
   m_col_name = m_AddDel.add_column(gettext("Databases"));
 
-  m_AddDel.signal_user_added().connect(sigc::mem_fun(*this, &Box_DataBases::on_AddDel_Add));
-  m_AddDel.signal_user_requested_edit().connect(sigc::mem_fun(*this, &Box_DataBases::on_AddDel_Edit));
-  m_AddDel.signal_user_requested_delete().connect(sigc::mem_fun(*this, &Box_DataBases::on_AddDel_Delete));
-  m_AddDel.signal_user_changed().connect(sigc::mem_fun(*this, &Box_DataBases::on_AddDel_Changed));
+  m_AddDel.signal_user_added().connect(sigc::mem_fun(*this, &Box_DataBases::on_adddel_Add));
+  m_AddDel.signal_user_requested_edit().connect(sigc::mem_fun(*this, &Box_DataBases::on_adddel_Edit));
+  m_AddDel.signal_user_requested_delete().connect(sigc::mem_fun(*this, &Box_DataBases::on_adddel_Delete));
+  m_AddDel.signal_user_changed().connect(sigc::mem_fun(*this, &Box_DataBases::on_adddel_Changed));
   
   set_use_list(); 
 
@@ -122,7 +122,7 @@ void Box_DataBases::on_button_connect()
   }
 }
 
-void Box_DataBases::on_AddDel_Add(const Gtk::TreeModel::iterator& row)
+void Box_DataBases::on_adddel_Add(const Gtk::TreeModel::iterator& row)
 {
   Glib::ustring strName = m_AddDel.get_value(row, m_col_name);
   if(!strName.empty())
@@ -136,7 +136,7 @@ void Box_DataBases::on_AddDel_Add(const Gtk::TreeModel::iterator& row)
       bool result = connection->create_database(strName);
       if(!result)
       {
-        g_warning("Box_DataBases::on_AddDel_Add(): create_database() failed: database_name=%s", strName.c_str());
+        g_warning("Box_DataBases::on_adddel_Add(): create_database() failed: database_name=%s", strName.c_str());
         handle_error();
       }
     }
@@ -173,14 +173,14 @@ sharedptr<SharedConnection> Box_DataBases::connect_to_server_with_connection_set
   return result;
 }
 
-void Box_DataBases::on_AddDel_Edit(const Gtk::TreeModel::iterator& row)
+void Box_DataBases::on_adddel_Edit(const Gtk::TreeModel::iterator& row)
 {
   m_strDatabaseName = m_AddDel.get_value_key(row);
  
   signal_selected.emit(m_strDatabaseName);
 }
 
-void Box_DataBases::on_AddDel_Delete(const Gtk::TreeModel::iterator& rowStart, const Gtk::TreeModel::iterator& /* rowEnd TODO */)
+void Box_DataBases::on_adddel_Delete(const Gtk::TreeModel::iterator& rowStart, const Gtk::TreeModel::iterator& /* rowEnd TODO */)
 {
   Glib::ustring strValue = m_AddDel.get_value_key(rowStart);
   if(!strValue.empty())
@@ -212,7 +212,18 @@ void Box_DataBases::load_from_document()
   {
     //Load server and user:
     m_Entry_Host->set_text(m_pDocument->get_connection_server());
-    m_Entry_User->set_text(m_pDocument->get_connection_user());
+
+    Glib::ustring user = m_pDocument->get_connection_user();
+
+    if(user.empty())
+    {
+      //Default to the UNIX user name, which is often the same as the Postgres user name:
+      const char* pchUser = getenv("$USER");
+      if(pchUser)
+        user = pchUser;
+    }
+    
+    m_Entry_User->set_text(user);
   }
 
 }
@@ -266,10 +277,16 @@ Box_DataBases::type_vecStrings Box_DataBases::get_database_names()
   return result;
 }
 
-void Box_DataBases::on_AddDel_Changed(const Gtk::TreeModel::iterator& /* row */, guint /* number */)
+void Box_DataBases::on_adddel_Changed(const Gtk::TreeModel::iterator& /* row */, guint /* number */)
 {
   //TODO: Get the old value and change the database name to the new value.
 }
 
+Gtk::Widget* Box_DataBases::get_default_button()
+{
+  return m_button_connect;
+}
+
+
 
 
