@@ -785,6 +785,11 @@ void AddDel::set_value(const Gtk::TreeModel::iterator& iter, guint col, bool bVa
   }
 }
 
+void AddDel::set_value_selected(guint col, const Gnome::Gda::Value& value)
+{
+  set_value(get_item_selected(), col, value);
+}
+
 void AddDel::remove_all_columns()
 {
   m_ColumnTypes.clear();
