@@ -47,7 +47,12 @@ void FlowTable::add(Gtk::Widget& first, Gtk::Widget& second)
 
 void FlowTable::add(Gtk::Widget& first)
 {
-  type_base::add(first);
+  FlowTableItem item;
+  item.m_first = &first;
+  item.m_second = 0;
+  m_children.push_back(item);
+
+  gtk_widget_set_parent(first.gobj(), GTK_WIDGET(gobj()));
 }
 
 void FlowTable::set_columns_count(guint value)
@@ -119,44 +124,58 @@ int FlowTable::get_item_requested_height(const FlowTableItem& item)
 
 int FlowTable::get_column_height(guint start_widget, guint widget_count, int& total_width)
 {
-    //init_db_details output parameter:
-    total_width = 0;
-  
-    //Just add the heights together:
-    int column_height = 0;
-    int column_width_first = 0;
-    int column_width_second = 0;
-    guint i = 0;
-    for(i = start_widget; i < (start_widget+widget_count);  ++i)
+  //init_db_details output parameter:
+  total_width = 0;
+
+  //Just add the heights together:
+  int column_height = 0;
+  int column_width_first = 0;
+  int column_width_second = 0;
+  int column_width_singles = 0;
+  guint i = 0;
+  for(i = start_widget; i < (start_widget+widget_count);  ++i)
+  {
+    FlowTableItem item = m_children[i];
+    int item_height = get_item_requested_height(item);
+
+    int item_width_first = 0;
+    int item_width_second = 0;
+    get_item_requested_width(item, item_width_first, item_width_second);
+
+    column_height += item_height;
+
+    //Add the padding if it's not the first widget, and if one is visible:
+    if( (i != start_widget) && item_height)
     {
-      FlowTableItem item = m_children[i];
-      int item_height = get_item_requested_height(item);
-      
-      int item_width_first = 0;
-      int item_width_second = 0;
-      get_item_requested_width(item, item_width_first, item_width_second);
+      column_height += m_padding;
+    }
 
-      column_height += item_height;
-
-      //Add the padding if it's not the first widget, and if one is visible:
-      if( (i != start_widget) && item_height)
-      {
-        column_height += m_padding;
-      }
-
-      if(item_height) //If one was visible.
+    if(item_height) //If one was visible.
+    {
+      if(child_is_visible(item.m_second))
       {
         column_width_first =MAX(column_width_first, item_width_first);
         column_width_second =MAX(column_width_second, item_width_second);
       }
-
+      else
+      {
+        //If there is only a first widget and no second one, then that first widget should take up the whole width,
+        //instead of increasing the width for the first sub-column:
+        column_width_singles = MAX(column_width_singles, item_width_first);
+      }
     }
 
-     total_width = column_width_first +  column_width_second;
-     if( (column_width_first > 0) && (column_width_second > 0) ) //Add padding if necessary.
-       total_width += m_padding;
-       
-    return column_height;
+  }
+
+   total_width = column_width_first +  column_width_second;
+
+   //See whether the single items need even more space:
+   total_width = MAX(total_width, column_width_singles);
+
+   if( (column_width_first > 0) && (column_width_second > 0) ) //Add padding if necessary.
+     total_width += m_padding;
+
+  return column_height;
 }  
 
 int FlowTable::get_minimum_column_height(guint start_widget, guint columns_count, int& total_width)
@@ -264,13 +283,14 @@ void FlowTable::assign_child(Gtk::Widget* widget, int x, int y)
   widget->size_allocate(child_allocation);
 }
 
-void FlowTable::get_item_max_width(guint start, int height, int& first_max_width, int& second_max_width)
+void FlowTable::get_item_max_width(guint start, int height, int& first_max_width, int& second_max_width, int& singles_max_width)
 {
   //Initialize output parameters:
   first_max_width = 0;
   second_max_width = 0;
+  singles_max_width = 0;
   
-  if(m_children.size() == 0)
+  if(m_children.empty())
     return;
 
   int height_so_far = 0;
@@ -284,18 +304,29 @@ void FlowTable::get_item_max_width(guint start, int height, int& first_max_width
 
     int height_item = 0;
 
+    int padding_above = 0;
     //Add padding above the item, if it is after another one.
     if( first_item_added && (child_is_visible(first) || child_is_visible(second)) )
-    {
-       height_item += m_padding;
-    }
+       padding_above += m_padding;
 
     int item_first_width = 0;
+    int singles_width = 0;
     if(child_is_visible(first))
     {
       Gtk::Requisition child_requisition;
-      gtk_widget_size_request(const_cast<GtkWidget*>(first->gobj()), &child_requisition); //TODO: This parameter should not be const: child->size_request(child_requisition);     
-      item_first_width = child_requisition.width;
+      gtk_widget_size_request(const_cast<GtkWidget*>(first->gobj()), &child_requisition); //TODO: This parameter should not be const: child->size_request(child_requisition);
+
+      if(child_is_visible(second))
+      {
+        //There are 2 widgets so put one in each sub-column, lined up with the widgets in the other rows:
+        item_first_width = child_requisition.width;
+      }
+      else
+      {
+        //There is only one widget, so let it take up the whole space and not affect the widths of the sub-columns:
+        singles_width = child_requisition.width;
+      }
+
       height_item = MAX(height_item, child_requisition.height);
       first_item_added = true;
     }
@@ -307,14 +338,18 @@ void FlowTable::get_item_max_width(guint start, int height, int& first_max_width
       gtk_widget_size_request(const_cast<GtkWidget*>(second->gobj()), &child_requisition); //TODO: This parameter should not be const: child->size_request(child_requisition);
       item_second_width = child_requisition.width;
       height_item = MAX(height_item, child_requisition.height);
-      first_item_added = true;                                       
+      first_item_added = true;
     }
 
+    if(height_item)
+      height_item += padding_above;
+          
     height_so_far += height_item;
     if(height_so_far <= height) //Don't remember the width details if the widgets are too high for the end of this column:
     {
       first_max_width = MAX(first_max_width, item_first_width);
       second_max_width = MAX(second_max_width, item_second_width);
+      singles_max_width = MAX(singles_max_width, singles_width);
     }
 
     ++i;
@@ -333,8 +368,10 @@ void FlowTable::on_size_allocate(Gtk::Allocation& allocation)
 
   //Discover the widths of the different parts of the first column:
   int first_max_width = 0;
-  int second_max_width= 0;
-  get_item_max_width(0, allocation.get_height(), first_max_width, second_max_width);  //TODO: Give the 2nd part of the column a bit more if the total needed is less than the allocation given.
+  int second_max_width = 0;
+  int singles_max_width = 0;
+  get_item_max_width(0, allocation.get_height(), first_max_width, second_max_width, singles_max_width);  //TODO: Give the 2nd part of the column a bit more if the total needed is less than the allocation given.
+           
   //Calculate where the columns should start on the x axis.
   int column_x_start = allocation.get_x();
   
@@ -351,22 +388,25 @@ void FlowTable::on_size_allocate(Gtk::Allocation& allocation)
 
     int item_height = get_item_requested_height(item);
 
-  
-   
     //Start a new column if necessary:
     int bottom = allocation.get_y() + allocation.get_height();   
     if( (column_child_y_start + item_height) > bottom)
     {
       //start a new column:
       column_child_y_start = allocation.get_y();
-      column_x_start += column_x_start_second + second_max_width + m_padding;
-
+      int column_x_start_plus_singles = column_x_start + singles_max_width;
+      column_x_start += column_x_start_second + second_max_width;
+      column_x_start = MAX(column_x_start, column_x_start_plus_singles); //Maybe the single items take up even more width.
+      column_x_start += m_padding;
+   
       {
         //Discover the widths of the different parts of this column:
-        int first_max_width = 0;
-        int second_max_width= 0;
-        get_item_max_width(i, allocation.get_height(), first_max_width, second_max_width);
+        first_max_width = 0;
+        second_max_width= 0;
+        singles_max_width = 0;
 
+        get_item_max_width(i, allocation.get_height(), first_max_width, second_max_width, singles_max_width);
+       
         column_x_start_second = column_x_start + first_max_width;
         if(first_max_width > 0) //Add padding between first and second sub sets of items, if there is a first set.
           column_x_start_second += m_padding;
@@ -376,22 +416,34 @@ void FlowTable::on_size_allocate(Gtk::Allocation& allocation)
     bool something_added = false;
     
     Gtk::Widget* first = item.m_first;
-    if(child_is_visible(first))
-    {
-      //Assign sign space to the child:
-      
-      //Make all the left edges line up:
-      assign_child(first, column_x_start, column_child_y_start);
-      something_added = true;
-    }
-
     Gtk::Widget* second = item.m_second;
     if(child_is_visible(second))
     {
-      //Assign sign space to the child:
+      //Place the 2 items so that they line up with the 2 items in other rows:
+      if(child_is_visible(first))
+      {
+        //Assign space to the child:
 
-      //Make all the left edges line up:
-      assign_child(second, column_x_start_second, column_child_y_start);
+        //Make all the left edges line up:
+        assign_child(first, column_x_start, column_child_y_start);
+        something_added = true;
+      }
+
+      if(child_is_visible(second))
+      {
+        //Assign space to the child:
+
+        //Make all the left edges line up:
+        assign_child(second, column_x_start_second, column_child_y_start);
+        something_added = true;
+      }
+    }
+    else if(child_is_visible(first))
+    {
+      //There is only one item - so let it take up the whole width of the column:
+        
+      //Assign space to the child:
+      assign_child(first, column_x_start, column_child_y_start);
       something_added = true;
     }
 
@@ -428,20 +480,40 @@ void FlowTable::on_add(Gtk::Widget* child)
 }
 
 
-void FlowTable::on_remove(Gtk::Widget* /* child */)
+void FlowTable::on_remove(Gtk::Widget* child)
 {
-  //TODO:
-  /*
-  type_vecChildren::iterator iterFind = std::find(m_children.begin(), m_children.end(), child);
-  if(iterFind != m_children.end())
+  if(child)
   {
-    m_children.erase(iterFind);
+    const bool visible = child->is_visible();
 
-    gtk_widget_unparent(child->gobj());
+  //g_warning("FlowTable::on_remove");
+    for(type_vecChildren::iterator iter = m_children.begin(); iter != m_children.end(); ++iter)
+    {
+      FlowTableItem& item = *iter;
 
-    //This is protected, but should be public: child.unparent();
+      if(item.m_first == child)
+      {
+            //g_warning("FlowTable::on_remove unparenting first");
+        gtk_widget_unparent(item.m_first->gobj()); //This is protected, but should be public: child.unparent();
+        item.m_first = 0;
+         
+       if(visible)
+          queue_resize();
+      }
+
+      if(item.m_second == child)
+      {
+        //g_warning("FlowTable::on_remove unparenting second");
+        gtk_widget_unparent(item.m_second->gobj()); //This is protected, but should be public: child.unparent();
+        item.m_second = 0;
+        
+        if(visible)
+          queue_resize();
+      }
+    }
   }
-  */
+
+ //g_warning("FlowTable::on_remove end");
 }
 
 
